#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/install.sh - libopenssl3 installation
#
# Creation   :  2017-06-05 holbru
# Last update:  $Id: install.sh 107239 2023-10-31 09:46:54Z hbfl $
#
# Copyright (c) 2017-2024 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# set package name
package_name=libopenssl3

# ---------------------------------------------------------------------------
# check for ssl link in /etc
# ---------------------------------------------------------------------------
if [ ! -L /etc/ssl ]
then
    cd /etc
    rm -f ssl
    ln -sf ../var/certs/ssl
fi

# ---------------------------------------------------------------------------
# compability to solve SSL issue
# 'SSL verify error: depth=1 error=unable to get local issuer certificate'  
# ---------------------------------------------------------------------------
if [ ! -L /var/lib/ca-certificates/openssl ]
then
    mkdir -p /var/lib/ca-certificates
    cd  /var/lib/ca-certificates
    ln -sf ../../../etc/ssl/certs openssl
fi

installed=$(/usr/bin/eisman check ${package_name})
if [ "${installed}" = "installed" ]
then
# ---------------------------------------------------------------------------
# hint to reboot and check that ssh connection work
# ---------------------------------------------------------------------------

# do not remove the spaces ;-),
# it is recomended for 'white' background
#                      1         2         3         4         5         6         7         8
#             12345678901234567890123456789012345678901234567890123456789012345678901234567890
echo
mecho --warn "                                                                       "
mecho --warn " Hint:                                                                 "
mecho --warn " Please check a new ssh connection before you close this session!      "
mecho --warn "                                                                       "
echo 
mecho --warn "                                                                       "
mecho --warn " Info:                                                                 "
mecho --warn " Core libraries or services have been updated.                         "
mecho --warn " Reboot is required to ensure that your system benefits from these     "
mecho --warn " updates.                                                              "
mecho --warn "                                                                       "
echo
fi

# ---------------------------------------------------------------------------
# clearup
# ---------------------------------------------------------------------------

/usr/bin/rm -f /usr/lib/libssl.so.3.0.8
/usr/bin/rm -f /usr/lib/libssl.so.3.1.1
/usr/bin/rm -f /usr/lib/libssl.so.3.1.2
/usr/bin/rm -f /usr/lib/libssl.so.3.1.3

/usr/bin/rm -f /usr/lib/libcrypto.so.3.0.8
/usr/bin/rm -f /usr/lib/libcrypto.so.3.1.1
/usr/bin/rm -f /usr/lib/libcrypto.so.3.1.2
/usr/bin/rm -f /usr/lib/libcrypto.so.3.1.3

/usr/bin/rm -f /usr/lib64/libssl.so.3.0.8
/usr/bin/rm -f /usr/lib64/libssl.so.3.1.1
/usr/bin/rm -f /usr/lib64/libssl.so.3.1.2
/usr/bin/rm -f /usr/lib64/libssl.so.3.1.3

/usr/bin/rm -f /usr/lib64/libcrypto.so.3.0.8
/usr/bin/rm -f /usr/lib64/libcrypto.so.3.1.1
/usr/bin/rm -f /usr/lib64/libcrypto.so.3.1.2
/usr/bin/rm -f /usr/lib64/libcrypto.so.3.1.3


exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
